@@ -111,7 +111,7 @@ class VariableClDesktopXsession(ReadonlyVariable):
         envXsessionFile = "/etc/env.d/90xsession"
         xsession = os.environ.get("XSESSION", None)
         desktopSession = os.environ.get("DESKTOP_SESSION", None)
-        if not xsession:
+        if self.Get('ur_login') == 'root' or not xsession:
             xsession = getValueFromConfig(envXsessionFile, "XSESSION")
         if xsession:
             if (desktopSession and any(x in desktopSession.lower()
